#!/bin/bash
# Buffalo LinkStation state checker
#
# This program checks if the shares on the LinkStation are accessible and if the Wake-On-LAN is running.
#
# by Matthias Arndt <marndt@asmsoftware.de>
# Optional arguments: --use-notify to use desktop notifaction instead of popup window

HOST="192.168.200.211"
LOCKFILE=$HOME/.linkstation-wol
ICONFILE=$HOME/Graphics/icons/NAS/ls-wsgl.ico
SHARES=$HOME/.linkstation-shares.txt

# check if the NAS answers via SMB
SMB_RESPONSE=0

smbclient -L //$HOST -N 2>/dev/null >$SHARES && SMB_RESPONSE=1

# generate status message
STATUS=0
if [ -f $LOCKFILE ]; then
# Wake-ON-LAN active
(( STATUS += 1 ))
fi

if [ $SMB_RESPONSE -eq 1 ]; then
# SMB responding
(( STATUS += 2 ))
fi

case $STATUS in
1)
  Message="Wake-On-LAN is active and mounting should be possible soon."
  ;;
2)
  Message="SMB share is available. Non local Wake-on-LAN is running."
  ;;
3)
  Message="NAS is available for mounting."
  ;;     
*)
  Message="NAS is currently not available."
  ;;
esac

if [[ "$1" = "--use-notify" ]]
then
notify-send -i $ICONFILE 'Buffalo LinkStation Status' "$Message"
else
# use zenity

DISPLAY=:0.0 zenity --info  \
   --title="Buffalo LinkStation Status"  \
   --text="$Message"
fi

exit 0
